@@ -17,3 +17,22 @@ sub do_apply {
 }
 
 1;
+
+__END__;
+
+=head1 NAME
+
+Reaction::InterfaceModel::Action::Role::SimpleMethodCall
+
+=head1 DESCRIPTION
+
+=head1 AUTHORS
+
+See L<Reaction::Class> for authors.
+
+=head1 LICENSE
+
+See L<Reaction::Class> for the license.
+
+=cut
+
