@@ -2,8 +2,9 @@ package Reaction::UI::ViewPort::Action;
 
 use Reaction::Class;
 
+use MooseX::Types::URI qw/Uri/;
 use MooseX::Types::Moose qw/Int Str/;
-use Reaction::Types::Core qw/NonEmptySimpleStr/;
+use MooseX::Types::Common::String qw/NonEmptySimpleStr/;
 
 use namespace::clean -except => [ qw(meta) ];
 
@@ -20,6 +21,8 @@ has method => (
   default => sub { 'post' }
 );
 
+has action => ( is => 'rw', isa => Uri );
+
 has changed => (
   is => 'rw',
   isa => Int,
@@ -59,7 +62,6 @@ sub sync_action_from_fields {
   }
 }
 
-
 __PACKAGE__->meta->make_immutable;
 
 1;
