@@ -2,14 +2,13 @@ package Reaction::UI::ViewPort::Field::RelatedObject;
 
 use Reaction::Class;
 use Scalar::Util 'blessed';
+use MooseX::Types::Moose qw/Str/;
 
 use namespace::clean -except => [ qw(meta) ];
 extends 'Reaction::UI::ViewPort::Field';
 
-
-
 has value_map_method => (
-  isa => 'Str', is => 'ro', required => 1, default => sub { 'display_name' },
+  isa => Str, is => 'ro', required => 1, default => sub { 'display_name' },
 );
 
 around _value_string_from_value => sub {
